get_degree: Compute the degree of each nodes in the network

View source: R/NetworkAnalysis.R

get_degreeR Documentation

Compute the degree of each nodes in the network

Description

Compute the degree of each nodes in the network

Usage

get_degree(graph, modes = c("in", "out", "total"))

Arguments

graph

an igraph object

modes

the type of degree: "in", "out", "total"

Value

a data.table of nodes degree


HospitalNetwork documentation built on April 4, 2025, 1:51 a.m.