get_matrix_bycluster: Function returning matrices of transfers within each by...

View source: R/NetworkAnalysis.R

get_matrix_byclusterR Documentation

Function returning matrices of transfers within each by clusters

Description

Function returning matrices of transfers within each by clusters

Usage

get_matrix_bycluster(mat, DT, clusters)

Arguments

mat

The adjacency matrix of the network

DT

A data table with at least a column 'node' and a factor column identifying the node's cluster

clusters

A unique character vector of the name of the column identifying the nodes' clusters


HospitalNetwork documentation built on April 4, 2025, 1:51 a.m.